# SWAGGER MERGER

* ###Merge multiple swagger files with single level ref tag ($ref) into one swagger file
* ###We will support multiple level ref tag soon!.
### $ref
> Includes a _single-level_ of swagger file.



For example:
```yaml
$ref: "./order.yaml"